@@ -4,10 +4,10 @@ print.activeset <- function(x, ...)
   print(x$call)
   cat("\nLoss value:", x$fval, "\n")
   cat("\nActive set fit:\n")
-  res.table <- t(data.frame(x$z, round(x$x,2)))
-  rownames(res.table) <- c("Predictor", "Fitted Values")
-  colnames(res.table) <- 1:length(x$z)
+  res.table <- t(data.frame(round(x$y, 3), round(x$x,3)))
+  rownames(res.table) <- c("Observed Values", "Fitted Values")
+  colnames(res.table) <- 1:length(x$x)
   print(t(res.table))
   cat("\n")
   invisible(x)
-}
\ No newline at end of file
+}
